@@ -1,5 +1,5 @@
 package App::CharmKit::Command::init;
-$App::CharmKit::Command::init::VERSION = '0.007';
+$App::CharmKit::Command::init::VERSION = '0.008';
 # ABSTRACT: Generate a charm project
 
 
@@ -71,28 +71,16 @@ sub execute {
     $project->{license} = prompt 'License [? for list]:',
       -menu => {
         agpl_3      => 'AGPL_3',
-        apache_1_1  => 'Apache_1_1',
         apache_2_0  => 'Apache_2_0',
         artistic_1  => 'Artistic_1_0',
         artistic_2  => 'Artistic_2_0',
         bsd         => 'BSD',
-        freebsd     => 'FreeBSD',
-        gfdl_1_2    => 'GFDL_1_2',
-        gfdl_1_3    => 'GFDL_1_3',
-        gpl_1       => 'GPL_1',
         gpl_2       => 'GPL_2',
         gpl_3       => 'GPL_3',
         lgpl_2_1    => 'LGPL_2_1',
         lgpl_3_0    => 'LGPL_3_0',
         mit         => 'MIT',
-        mozilla_1_0 => 'Mozilla_1_0',
-        mozilla_1_1 => 'Mozilla_1_1',
-        openssl     => 'OpenSSL',
-        perl_5      => 'Perl_5',
-        qpl_1_0     => 'QPL_1_0',
-        ssleay      => 'SSLeay',
-        sun         => 'Sun',
-        zlib        => 'Zlib',
+        perl_5      => 'Perl_5'
       },
       '>';
 
@@ -120,7 +108,7 @@ App::CharmKit::Command::init - Generate a charm project
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
