@@ -1,7 +1,8 @@
 package App::CharmKit::Role::Init;
-$App::CharmKit::Role::Init::VERSION = '0.007';
+$App::CharmKit::Role::Init::VERSION = '0.008';
 # ABSTRACT: Initialization of new charms
 
+use App::CharmKit::Sys qw(execute);
 use YAML::Tiny;
 use JSON::PP;
 use Software::License;
@@ -41,6 +42,11 @@ perltidy.LOG
     );
     $path->child('.gitignore')->spew_utf8($gitignore);
 
+    # git init
+    if (!$path->child('.git')->exists) {
+        execute(['git', 'init', $project->{name}]);
+    }
+
     # tests/tests.yaml
     my $yaml = YAML::Tiny->new({packages => ['perl', 'make']});
     $yaml->write($path->child('tests/tests.yaml'));
@@ -90,21 +96,49 @@ done_testing;
     my $notice  = $license->notice;
 
     # copyright
-    ( my $copyright = qq{Format: http://dep.debian.net/deps/dep5/
+    (   my $copyright =
+          qq{Format: http://dep.debian.net/deps/dep5/
 
 Files: *
 Copyright: $year, $project->{maintainer}
 License: $project->{license}
   <Needs license text here>
-});
+}
+    );
     $path->child('copyright')->spew_utf8($copyright);
 
     # README.md
     (   my $readme = qq{
-# $project->{name} - $project->{summary}
+# Juju charm for $project->{name}
 
 $project->{description}
 
+Made with [CharmKit](https://github.com/battlemidget/App-CharmKit)
+
+## How to Deploy
+
+### With CharmKit
+
+```console
+> charmkit get <github-user>/$project->{name}
+> charmkit deploy <charm>
+```
+
+### Juju
+
+#### Charm Store
+
+```console
+> juju deploy cs:trusty/$project->{name}
+```
+
+#### Source
+
+```console
+> mkdir -p ~/charms && git clone https://github.com/<github-user>/$project->{name}
+> juju deploy --repository=charms local:<series>/$project->{name}
+```
+
 # AUTHOR
 
 $project->{maintainer}
@@ -120,7 +154,8 @@ $notice
     );
     $path->child('README.md')->spew_utf8($readme);
 
-    ( my $makefile = q{PWD := $(shell pwd)
+    (   my $makefile =
+          q{PWD := $(shell pwd)
 HOOKS_DIR := $(PWD)/hooks
 TEST_DIR := $(PWD)/tests
 
@@ -148,7 +183,8 @@ clean: ensure_ck
 	@charmkit clean
 
 .PHONY: pack test lint ensure_ck
-});
+}
+    );
     $path->child('Makefile')->spew_utf8($makefile);
 
 }
@@ -167,7 +203,7 @@ App::CharmKit::Role::Init - Initialization of new charms
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 METHODS
 
